@@ -457,9 +457,9 @@ class Controll(Base):
     name_en = Column('control_name_en', String(100))
 
     # Короткое наименование
-    short_name_ru = Column('control_name_ru', String)
-    short_name_kz = Column('control_name_kz', String)
-    short_name_en = Column('control_name_en', String)
+    short_name_ru = Column('control_short_name_ru', String)
+    short_name_kz = Column('control_short_name_kz', String)
+    short_name_en = Column('control_short_name_en', String)
 
     # Максимальная оценка
     max_ball = Column('control_max_ball', Integer)
